/*
 * Reads the content from the markdown file /content/fit-standards/bedienungshilfe.md
 *
 */

import fs from 'fs'
import path from 'path'
import { remark } from 'remark'
import html from 'remark-html'

export default function loadAndPrepareMarkdown(selectedServiceName: string, folder: string) {
    const markdownFileContent: string = loadMarkdown()
    const content: string = prepareContentFromMarkdown(markdownFileContent)
    return content
}

function loadMarkdown() {
    const fullPath: string = path.join(process.cwd(), 'content/fit-standards/bedienungshilfe.md')
    const markdownContent: string = fs.readFileSync(fullPath, 'utf8')
    return markdownContent
}

function prepareContentFromMarkdown(markdownContent: string) {
    // eslint-disable-next-line no-unused-vars
    const [header, metadata, text] = markdownContent.replace(/\r\n/g, '\n').split('---')
    // const content: ServiceContent = parseMetadata(metadata)
    return parseTextToHTMLString(text)
}

function parseTextToHTMLString(markdownText: string) {
    const sanitizedMarkdownText: string = sanitizeMarkdownText(markdownText)
    const processedContent = remark().use(html).processSync(sanitizedMarkdownText)
    const htmlContent: string = processedContent.toString()
    return htmlContent
}

function sanitizeMarkdownText(markdownText: string) {
    // trim whitespaces; replace line breaks with and remove multiple whitespaces
    return markdownText.trim().replace(/ +(?= )/g, ' ')
}
