import { ServiceContent } from 'types/ServiceContent'
import loadAndPrepareMarkdown from './use-markdown-parser'
import fs from 'fs'
import path from 'path'

const useContent = (folder = 'resources') => {
    const contents: ServiceContent[] = readMarkdownFilesFrom(folder)

    const contentByServiceName = (selectedServiceName: string) => {
        if (contents.length > 0) {
            // try to read entry
            // console.log('contents array initialized', contents.length)
            // return
        }
        const content: ServiceContent = getContentByServiceName(selectedServiceName, folder)
        return content
    }

    return {
        contents,
        contentByServiceName,
    }
}

function getContentByServiceName(selectedServiceName: string, folder: string) {
    return prepareServiceContent(selectedServiceName, folder)
}

function prepareServiceContent(selectedServiceName: string, folder: string) {
    const content: ServiceContent = loadAndPrepareMarkdown(selectedServiceName, folder)
    return content
}

function readMarkdownFilesFrom(folder = 'resources'): ServiceContent[] {
    const resourcesDirectory = path.join(process.cwd(), 'content', folder)

    // read all folder in 'resources'-directory
    const serviceDirectories: string[] = fs.readdirSync(resourcesDirectory, { withFileTypes: true })
        .filter((serviceDirectory: fs.Dirent) => serviceDirectory.isDirectory())
        .map((serviceDirectory: fs.Dirent) => serviceDirectory.name)

    return serviceDirectories.map((serviceDirectory: string) => {
        return loadAndPrepareMarkdown(serviceDirectory, folder)
    })
}

export default useContent
